;; ~/.emacs: init file for Emacs
;;
;; $Id: emacs.el,v 1.13 2004/06/12 18:09:07 deskpot Exp $

;; Define user-init-directory for emacsen, that don't have it.
(unless (boundp 'user-init-directory)
  (defvar user-init-directory "~/.emacs.d/"
    "Directory where user-installed init files may go."))

;; add per-user lisp directories to the load-path
;(add-to-list 'load-path (expand-file-name "lisp" user-init-directory))
(add-to-list 'load-path (expand-file-name "lisp" "~/src"))

;; Cyrillic support
;;
(set-language-environment "Cyrillic-KOI8")
(set-terminal-coding-system 'koi8-r)
(set-keyboard-coding-system 'koi8-r)
(set-clipboard-coding-system 'compound-text-with-extensions)

(put-charset-property 'cyrillic-iso8859-5
		      'preferred-coding-system 'koi8-r)

(unless (coding-system-p 'cp1251)
  (codepage-setup 1251)
  (define-coding-system-alias 'windows-1251 'cp1251))
(unless (coding-system-p 'koi8-u)
  (define-coding-system-alias 'koi8-u 'koi8-r))

;; Set misc. variables
;;
(setq inhibit-startup-message t
      initial-scratch-message nil
      report-emacs-bug-no-explanations t

      frame-title-format (concat invocation-name "@" system-name)
      window-min-height 2
      use-dialog-box nil
      visible-bell t
      line-number-mode t
      column-number-mode t
      transient-mark-mode t
      cursor-in-non-selected-windows nil

      scroll-step 2
      next-line-add-newlines nil
      sentence-end-double-space nil
      mouse-yank-at-point t

      auto-save-default t
      auto-save-interval 500
      auto-save-timeout 900
      auto-save-list-file-prefix (expand-file-name "auto-save-list/saves-"
						   user-init-directory)

      make-backup-files nil)

(setq-default fill-column 72)

;; Enable narrow-to-region (C-x n n)
(put 'narrow-to-region 'disabled nil)
;; I hate the yes/no prompt
(fset 'yes-or-no-p 'y-or-n-p)
;; use cperl-mode as perl-mode
(fset 'perl-mode 'cperl-mode)
;; use sh-mode for "*/etc/rc(.*)?"
(add-to-list 'auto-mode-alist '("/etc/rc\\($\\|\\.\\)" . sh-mode))

;; Toggle automatic file compression and uncompression
(auto-compression-mode t)
;; Use auto-fill in text modes
(add-hook 'text-mode-hook 'turn-on-auto-fill)
;; Use ANSI colors within shell-mode
(add-hook 'shell-mode-hook 'ansi-color-for-comint-mode-on)

;; I prefer unidiffs
(setq diff-switches "-u")

;; Syntax highlighting and parenthesis
;;
(global-font-lock-mode t)
(show-paren-mode t)
(blink-cursor-mode nil)

;; Set up programming modes
;;
(setq-default comment-start "#"
	      c-recognize-knr-p nil)
(setq comment-padding nil
      c-default-style "bsd"

      cperl-indent-level default-tab-width
      cperl-brace-offset 0
      cperl-continued-brace-offset (- default-tab-width)
      cperl-label-offset (- default-tab-width)
      cperl-continued-statement-offset default-tab-width
      cperl-merge-trailing-else nil
      cperl-extra-newline-before-brace t

      sh-indentation default-tab-width
      sh-shell 'sh
      sh-indent-for-then 0
      sh-indent-for-do 0
      sh-indent-after-do '+
      sh-indent-comment t
      sh-basic-offset default-tab-width
      sh-shell-file "/bin/sh"

      tcl-indent-level default-tab-width
      tcl-continued-indent-level default-tab-width)

;; fix commenting in certain modes
;;
(defun vk-fix-comment-hash ()
  "Set comment-start to \"#\" (no spaces around) and unset comment-end."
  (interactive)
  (setq comment-start "#"
	comment-end ""))

(defun vk-fix-comment-double-slash ()
  "Set comment-start to \"//\" (no spaces around) and unset comment-end."
  (interactive)
  (setq comment-start "//"
	comment-end ""))

(add-hook 'cperl-mode-hook 'vk-fix-comment-hash)
(add-hook 'sh-mode-hook 'vk-fix-comment-hash)
(add-hook 'tcl-mode-hook 'vk-fix-comment-hash)
(add-hook 'c++-mode-hook 'vk-fix-comment-double-slash)

;; desire.el
(require 'desire)
(add-to-list 'desire-load-path
	     (expand-file-name "desire" user-init-directory))
(add-to-list 'auto-mode-alist
	     (cons (concat (regexp-quote desire-extension) "\\'")
		   'emacs-lisp-mode))

;; misc. faces
(desire 'faces)
;; load mail & news settings
(desire 'mailnews)
;; web-related stuff
(desire 'www)

;; keybindings
;;
(global-set-key [(meta \?)] 'help-command)

;; fixme: this breaks isearch
(global-set-key [scroll-lock] 'ignore)
(global-set-key [key-8] 'ignore)

(global-set-key [(control c) (i)] 'overwrite-mode)
(global-set-key [(control c) (k)] 'kill-this-buffer)
(global-set-key [(control c) (r)] 'revert-buffer)
(global-set-key [(control c) (f)] 'font-lock-mode)

(autoload 'goto-last-buffer "goto-last-buffer" nil t)
(global-set-key [(control c) (b)] 'goto-last-buffer)
(global-set-key [(control c) (B)] 'buffer-menu)

(autoload 'comment-region-or-line "comment-region-or-line" nil t)
(global-set-key [(control c) (q)] 'comment-region-or-line)

;; version control is handy
(require 'vc)
(setq vc-follow-symlinks t)
(global-set-key [(control x) (control q)] 'vc-toggle-read-only)

;; find-file-at-point
(setq ffap-machine-p-known 'accept)
(require 'ffap)
(ffap-bindings)

;; misc. requires and autoloads
;;
(autoload 'delete-all-comments "delete-all-comments" nil t)
(autoload 'clone-line "clone-line" nil t)

(desire 'boxquote)
(desire 'thinks)
(desire 'fortune)
(desire 'find-library)

(desire 'auctex)
(desire 'csh-mode)
(desire 'css-mode)
(desire 'php-mode)
(desire 'xrdb-mode)

(desire 'tramp)
(desire 'gnuserv)

;; finally, make customize living in separate file, if it isn't yet there
(unless custom-file
  (setq custom-file (expand-file-name "custom.el" user-init-directory))
  (if (file-exists-p custom-file)
      (load-file custom-file)))

(if (and (eq window-system 'x) (not (featurep 'mwheel)))
    (require 'mouse-wheel))

(require 'ange-ftp)
