;; Gnus is a versatile Emacs news & mail reader
;;
;; $Id: gnus.el,v 1.11 2004/07/22 15:35:53 deskpot Exp $

(setq gnus-agent nil
      gnus-interactive-exit nil
      gnus-novice-user nil
      gnus-bug-create-help-buffer nil

      gnus-save-killed-list nil
      gnus-check-new-newsgroups nil
      gnus-save-newsrc-file nil
      gnus-read-newsrc-file nil

      gnus-extra-headers nil
      gnus-keep-same-level 'best

      gnus-parameters
      '(("^nnml:.*"
	 (gnus-use-scoring nil))
	("^nnml:list\\."
	 (gnus-use-scoring t)
	 (subscribed . t))
	("^nnml:mail\\.misc"
	 (nnml-inhibit-expiry t)))

      gnus-permanently-visible-groups "^nnml:archive$"

      gnus-auto-expirable-newsgroups
      "^nnml:list\\.\\|^nnml:junk\\.\\|^nnml:mail\\.root$"
      gnus-total-expirable-newsgroups gnus-auto-expirable-newsgroups)

;; topic mode is nice
(add-hook 'gnus-group-mode-hook 'gnus-topic-mode)


;; composing and sending messages
;;
(setq gnus-posting-styles
      '((t
	 (body "\n")
	 (signature-file "~/.signature"))
	(message-news-p
	 (address "deskpot@msk.yell.ru")
	 (mail-copies-to "never"))
	("gmane\\..*"
	 (address "deskpot@despammed.com")
	 (mail-copies-to "never"))
	("list\\..*"
	 (mail-copies-to "never")))

      gnus-group-posting-charset-alist
      '(("^fido7\\.[^,]*\\(,[ 	\n]*fido7\\.[^,]*\\)*$" koi8-r (koi8-r))
	(message-this-is-news nil t)
	(message-this-is-mail nil t))

      message-dont-reply-to-names "deskpot\\|vas@land.ru"
      gnus-ignored-from-addresses message-dont-reply-to-names

      message-use-followup-to t

      ;; MFT generation
      message-subscribed-address-functions
      '(gnus-find-subscribed-addresses)

      message-subject-trailing-was-query t
      message-subject-re-regexp
      "^[ \t]*\\`\\(re\\([[(^][0-9]+[])]?\\)?:[ \t]*\\)+"

      ;; archive sent articles
      gnus-gcc-mark-as-read t

      gnus-message-archive-group
      '((if (and (message-mail-p)
		 (let ((addr
			(car (car
			      (mapcar 'funcall
				      message-subscribed-address-functions)))))
		   (if addr
		       (if (string-match addr
					 (or (message-fetch-field "To")
					     ""))
			   nil t)
		     t)))
	    "archive"))

      gnus-message-archive-method
      '(nnml ""))

(add-to-list 'message-shoot-gnksa-feet 'multiple-copies)
;; work around a bug in pre-21.4 Emacs:
(setq message-syntax-checks
      '((sender . disabled) (control-chars . disabled)))

;; auto-sign mail messages
;; note, that this construction disables auto-encrypting
(add-hook 'message-setup-hook 'mml-vk-maybe-sign)
(add-hook 'gnus-message-setup-hook 'mml-vk-maybe-sign)
(add-hook 'gnus-message-setup-hook 'mml-vk-remove-broken-sign)
(add-hook 'tc-pre-hook 'mml-unsecure-message)


;; reading mail
;;
(setq gnus-secondary-select-methods '((nnml ""))
      mail-source-delete-incoming t

      mail-sources
      (list
       (let ((dir (getenv "MAILDIR")))
	 (if (and dir (file-directory-p dir))
	     '(maildir :plugged t)
	   '(file :plugged t))))

      nnmail-crosspost nil
      nnmail-treat-duplicates 'delete
      nnmail-expiry-wait 14
      nnmail-split-methods 'nnmail-split-fancy

      nnmail-split-fancy
      '(|
	;; fido -- no spam filter
	;;
	("newsfetch" "fido7.ru.guitar" "fido.ru.guitar")
	("newsfetch" "fido7.ru.pickup" "fido.ru.pickup")

	("x-spam-status" "Yes" "junk.spam") ;; SpamAssassin

	;; read-only lists
	;;
	("to" "anekdot-daily-mail@anekdot\\.ru" "list.humor")
	("x-maillist-id" "2[01]-MIME-KOI" "list.humor")
	("list-id" "<inet\\.bugtraq\\.bred\\.subscribe\\.ru>" "list.humor")

	("to" "jerryrubin@kaa\\.ru" "list.announces")
	("list-post" "<mailto:announce@*apache\\.org>" "list.announces")
	("x-xemacs-list" "announce" "list.announces")

	("sender" "owner-fvwm-announce@hpc\\.uh\\.edu" "list.announces")
	("delivered-to" "netbsd-announce@netbsd.\\org" "list.announces")
	("from" "mycgiserver <automated@mycgiserver\\.com>" "list.announces")

	;; bounces and virus alerts
	(from "\\(MAILER-DAEMON\\|postmaster\\)@" "junk.bounces")

	;; read-write lists
	;;
	(to "trivial-cite-users@shasta\\.cs\\.uiuc\\.edu"
	    "list.trivial-cite-users")

	("x-xemacs-list" "users-ru" "list.xemacs-users-ru")

	;; all other mail to my mtu mailbox is spam
	("received" "from mail\\.mtu\\.ru" "junk.spam")

;	(any "replies@deskpot.yell.ru"
;	    (| ("subject" "re:.*" "mail.misc")
;	       ("references" ".*@.*" "mail.misc")
;	       "junk.spam")) ;; probably spam

	;; filter out the remaining lists, except RT
	("rt-ticket" "#" "mail.misc")
	("precedence" "\\(bulk\\|list\\)" "junk.spam")

	;; root mail
	("to" "[Rr][Oo][Oo][Tt]@[a-z0-9.-]+$" "mail.root")

	;; last resort
	"mail.misc"))

(if (boundp 'gnus-extra-headers)
    (setq nnmail-extra-headers gnus-extra-headers))


;; misc. displaying
;;
(setq gnus-treat-display-smileys nil
      gnus-treat-display-x-face nil
      gnus-treat-display-face nil
      gnus-treat-date-local 'head
      gnus-treat-hide-headers 'head
      gnus-treat-hide-boring-headers 'head
      gnus-treat-strip-leading-blank-lines t
      gnus-treat-strip-trailing-blank-lines t
      gnus-treat-strip-cr t
      gnus-treat-body-boundary nil

      gnus-group-charset-alist nil
      gnus-default-charset 'koi8-r
      gnus-summary-show-article-charset-alist
      '((1 . koi8-r) (2 . windows-1251) (3 . utf-8) (4 . iso-8859-1))

      gnus-simplify-subject-functions '(gnus-simplify-subject
					gnus-simplify-whitespace)

      gnus-unbuttonized-mime-types '("text/plain"
				     "application/pgp-signature"))

(setq gnus-visible-headers "^\\(\\(Resent-\\)?From\\|Newsgroups\\|Subject\\|Date\\|\\(Followup\\|Reply\\|Posted\\)-To\\|Summary\\|Keywords\\|To\\|B?Cc\\|Mail-Copies-To\\|Gnus-Warning\\|X-Sent\\|User-Agent\\|X-Newsreader\\|X-Mailer\\):")

(setq gnus-cite-attribution-suffix "\\(\\(wrote\\|writes\\|>\\|\\|\\(()\\)?\\)\\( to [a-z ]+\\)?:\\|----- ?\\(Original Message\\| \\) ?-----\\)[ 	]*$")

(setq gnus-cite-unsightly-citation-regexp "^-----\\(Original Message\\| \\)-----\n\\(From\\|\\): \\(.+\n\\)+\n")

;(require 'gnus-art)
;(add-to-list 'gnus-boring-article-headers 'newsgroups)
;(add-to-list 'gnus-boring-article-headers 'to-list)
;(add-to-list 'gnus-boring-article-headers 'cc-list)

;; strikethru is annoying
(setq
 gnus-emphasis-alist
 (let ((format
	"\\(\\s-\\|^\\|\\=\\|[-\"]\\|\\s(\\)\\(%s\\(\\w+\\(\\s-+\\w+\\)*[.,]?\\)%s\\)\\(\\([-,.;:!?\"]\\|\\s)\\)+\\s-\\|[?!.]\\s-\\|\\s)\\|\\s-\\)")
       (types
	'(("\\*" "\\*" bold)
	  ("_" "_" underline)
	  ("/" "/" italic)
	  ("_/" "/_" underline-italic)
	  ("_\\*" "\\*_" underline-bold)
	  ("\\*/" "/\\*" bold-italic)
	  ("_\\*/" "/\\*_" underline-bold-italic))))
   `(,@(mapcar
	(lambda (spec)
	  (list
	   (format format (car spec) (cadr spec))
	   2 3 (intern (format "gnus-emphasis-%s" (nth 2 spec)))))
	types)
       ("\\(\\s-\\|^\\)\\(_\\(\\(\\w\\|_[^_]\\)+\\)_\\)\\(\\s-\\|[?!.,;]\\)"
	2 3 gnus-emphasis-underline))))


;; set up scoring
(setq gnus-score-thread-simplify t
      gnus-score-expiry-days 14)


;; last, but not least, set up faces
;;
(desire 'gnus-faces)
