;; mail and news functions should go here and be byte-compiled
;;
;; $Id: mailfuncs.el,v 1.3 2004/01/17 21:45:49 deskpot Exp $

;; this is for the header-action-list
;;
(defun header-action-fido7 ()
  ;; add fido7 password to the keywords
  (if (and (boundp 'header-action-fido7-password) header-action-fido7-password)
      (save-excursion
	(save-restriction
	  ;; does keywords header exist?
	  (if (mail-position-on-field "Keywords")
	      (progn
		(narrow-to-region (+ (point-at-bol) 10) (point-at-eol))
		(goto-char (point-at-eol))
		(unless (search-backward header-action-fido7-password nil t)
		  ;; there is something in the keywords -- but not the password
		  (insert " " header-action-fido7-password)))
	    ;; there's no such header, so just add the password
	    (insert header-action-fido7-password)))))

  ;; add x-comment-to, if not already there
  (if message-reply-headers
      (let ((whofrom (mail-header-from message-reply-headers)))
	(save-excursion
	  (unless (mail-position-on-field "X-Comment-To")
	    (insert whofrom)))))
  )

;; Should we sign the message
;;
(defun mml-vk-maybe-sign ()
  "Sign the message with PGP/MIME (if mml-vk-maybe-sign-pgpmime is bound
and returns anything, but nil) or PGP (same with mml-vk-maybe-sign-pgp)."
  (interactive)
  (cond ((and (fboundp 'mml-vk-maybe-sign-pgpmime) (mml-vk-maybe-sign-pgpmime))
	 (mml-secure-message-sign-pgpmime))
	((and (fboundp 'mml-vk-maybe-sign-pgp) (mml-vk-maybe-sign-pgp))
	 (mml-secure-message-sign-pgp))))

;; sign all the mail messages (gmane.* newsgroups are mailing lists)
(defun mml-vk-maybe-sign-pgpmime ()
  (cond ((message-mail-p)
	 t)
;	((message-news-p)
;	 (let ((groups (message-fetch-field "Newsgroups")))
;	   (if (and groups (string= (substring groups 0 6) "gmane."))
;	       t)))
	))

;; sign all the news messages, except fido7 hierarchy
;(defun mml-vk-maybe-sign-pgp ()
;  (if (message-news-p)
;      (let ((groups (message-fetch-field "Newsgroups")))
;	(if (and groups (not (string= (substring groups 0 6) "fido7.")))
;	    t))))

(defun mml-vk-remove-broken-sign ()
  "Remove a \"^<\#secure method=pgpmime mode=sign>$\" below the first line
of the message body."
  (interactive)
  (save-excursion
    (message-goto-body)
    (when (and (eq (forward-line) 0)
	       (search-forward-regexp "^<\#secure method=pgpmime mode=sign>$"
				      nil t))
      (delete-region (point-at-bol) (point-at-eol))
      (unless (eq (point) (point-max))
	(delete-char 1)))))

;; forget the passphrase, if it's out there
(defun gpg-vk-passphrase-forget ()
  (if (and (featurep 'gpg) gpg-passphrase)
      (gpg-passphrase-forget)))

(defun vk-break-cite ()
  "Remove the current line and add two blank lines: before and after it."
  (interactive)
  (save-excursion
    (delete-region (point-at-bol) (point-at-eol))
    (newline 2))
  (forward-line 1))

;; define a couple of recoding shortcuts for Gnus and non-MULE emacsen
;;
(defun gnus-summary-vk-recode-from-iso ()
  "Pipes the article through `iconv -f iso8859-5 -t koi8-r` and re-highlightes it."
  (interactive)
  (gnus-summary-pipe-message "iconv -f iso8859-5 -t koi8-r")
  (gnus-article-highlight)
  (gnus-article-emphasize))

(defun gnus-summary-vk-recode-from-win ()
  "Pipes the article through `iconv -f cp1251 -t koi8-r` and re-highlightes it."
  (interactive)
  (gnus-summary-pipe-message "iconv -f cp1251 -t koi8-r")
  (gnus-article-highlight)
  (gnus-article-emphasize))

(defun tc-parse-xct (str)
  "tc-parse-xct uses mail-extr to get xct into tc-strings-list."
  (let ((xct (mail-extract-address-components str)))
    (if xct
	(setq tc-strings-list
	      (cons (cons "xct"
			  (or (car xct)
			      (nth 1 xct)))
		    tc-strings-list)))))

(defun tc-vk-xct-attribution ()
  "kai-tc-simple-attribution, hacked to write X-Comment-To (xct) data."
  (let ((date (assoc "date" tc-strings-list))
	(email (assoc "email-addr" tc-strings-list))
        (name (assoc "real-name" tc-strings-list))
	(xct (cdr (assoc "xct" tc-strings-list))))
    (if (and (null name) (null email))
	"An unnamed person wrote:\n\n"
      (if (null date)
	  (concat (cdr (or name email)) " wrote:\n\n")
	(concat "On " (cdr date) ", " (cdr (or name email)) " wrote"
		(if xct
		    (cond ((string= xct user-full-name)
			   "") ;; " to me"
			  ((string= xct "All")
			   "") ;; " to everybody"
			  (t
			   (concat " to " xct))))
		":\n\n")))))

(defun tc-vk-date-attribution ()
  "kai-tc-simple-attribution, hacked to write sender's date as is."
  (let ((email (assoc "email-addr" tc-strings-list))
        (name (assoc "real-name" tc-strings-list)))
    (if (and (null name) (null email))
	"An unnamed person wrote:\n\n"
      (if (null message-reply-headers)
	  (concat (cdr (or name email)) " wrote:\n\n")
	(concat "On " (mail-header-date message-reply-headers) ", "
		(cdr (or name email)) " wrote:\n\n")))))
